#
# spec file for package python-Werkzeug-doc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-Werkzeug-doc
Version:        0.14.1
Release:        lp152.3.2
Summary:        Documentation for python-Werkzeug
License:        BSD-3-Clause
Group:          Documentation/Other
URL:            http://werkzeug.pocoo.org/
Source:         https://files.pythonhosted.org/packages/source/W/Werkzeug/Werkzeug-%{version}.tar.gz
BuildRequires:  python3-Sphinx
BuildRequires:  python3-Werkzeug = %{version}
BuildRequires:  python3-setuptools
Provides:       %{python_module Werkzeug-doc = %{version}}
BuildArch:      noarch

%description
Documentation and examples for python-Werkzeug

%prep
%setup -q -n Werkzeug-%{version}
sed -i "s/\r//" LICENSE # Fix wrong EOL-encoding
sed -i "1d" examples/manage-{i18nurls,simplewiki,shorty,couchy,cupoftee,webpylike,plnt,coolmagic}.py # Fix non-executable scripts

%build
# Not needed

%install
cd docs && make html && rm -rf _build/html/.buildinfo # Build HTML Documentation

%files
%license LICENSE
%doc AUTHORS README.rst CHANGES.rst
%doc docs/_build/html
%doc examples

%changelog
* Wed Jan  3 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 0.14.1:
  * Resolved a regression with status code handling in the integrated
    development server.
- changes from version 0.14:
  * HTTP exceptions are now automatically caught by
    Request.application.
  * Added support for edge as browser.
  * Added support for platforms that lack SpooledTemporaryFile.
  * Add support for etag handling through if-match
  * Added support for the SameSite cookie attribute.
  * Added werkzeug.wsgi.ProxyMiddleware
  * Implemented has for NullCache
  * get_multi on cache clients now returns lists all the time.
  * Improved the watchdog observer shutdown for the reloader to not
    crash on exit on older Python versions.
  * Added support for filename* filename attributes according to RFC
    2231
  * Resolved an issue where machine ID for the reloader PIN was not
    read accurately on windows.
  * Added a workaround for syntax errors in init files in the
    reloader.
  * Added support for using the reloader with console scripts on
    windows.
  * The built-in HTTP server will no longer close a connection in
    cases where no HTTP body is expected (204, 204, HEAD requests
    etc.)
  * The EnvironHeaders object now skips over empty content type and
    lengths if they are set to falsy values.
  * Werkzeug will no longer send the content-length header on 1xx or
    204/304 responses.
  * Cookie values are now also permitted to include slashes and equal
    signs without quoting.
  * Relaxed the regex for the routing converter arguments.
  * If cookies are sent without values they are now assumed to have an
    empty value and the parser accepts this. Previously this could
    have corrupted cookies that followed the value.
  * The test Client and EnvironBuilder now support mimetypes like the
    request object does.
  * Added support for static weights in URL rules.
  * Better handle some more complex reloader scenarios where sys.path
    contained non directory paths.
  * EnvironHeaders no longer raises weird errors if non string keys
    are passed to it.
* Fri Dec  8 2017 arun@gmx.de
- specfile:
  * added CHANGES.rst and README.rst to %%doc section
  * require requests and hypothesis for tests
- update to version 0.13:
  * Deprecate support for Python 2.6 and 3.3. CI tests will not run
    for these versions, and support will be dropped completely in the
    next version. (pallets/meta#24)
  * Raise TypeError when port is not an integer. (#1088)
  * Fully deprecate werkzeug.script. Use Click instead. (#1090)
  * response.age is parsed as a timedelta. Previously, it was
    incorrectly treated as a datetime. The header value is an integer
    number of seconds, not a date string. (#414)
  * Fix a bug in TypeConversionDict where errors are not propagated
    when using the converter. (#1102)
  * Authorization.qop is a string instead of a set, to comply with RFC
    2617. (#984)
  * An exception is raised when an encoded cookie is larger than, by
    default, 4093 bytes. Browsers may silently ignore cookies larger
    than this. BaseResponse has a new attribute max_cookie_size and
    dump_cookie has a new argument max_size to configure this. (#780,
    [#1109])
  * Fix a TypeError in
    werkzeug.contrib.lint.GuardedIterator.close. (#1116)
  * BaseResponse.calculate_content_length now correctly works for
    Unicode responses on Python 3. It first encodes using
    iter_encoded. (#705)
  * Secure cookie contrib works with string secret key on Python
    3. (#1205)
  * Shared data middleware accepts a list instead of a dict of static
    locations to preserve lookup order. (#1197)
  * HTTP header values without encoding can contain single
    quotes. (#1208)
  * The built-in dev server supports receiving requests with chunked
    transfer encoding. (#1198)
* Tue Aug  8 2017 tbechtold@suse.com
- update to 0.12.2:
  - Fix regression: Pull request ``#892`` prevented Werkzeug from correctly
    logging the IP of a remote client behind a reverse proxy, even when using
    `ProxyFix`.
  - Fix a bug in `safe_join` on Windows.
* Tue Apr  4 2017 jmatejek@suse.com
- update to 0.12.1
- use python3-Sphinx for build
* Thu Sep 15 2016 toddrme2178@gmail.com
- update to version 0.11.11:
  * Fix JSONRequestMixin for Python3. See #731
  * Fix broken string handling in test client when passing
    integers. See #852
  * Fix a bug in "parse_options_header" where an invalid content type
    starting with comma or semi-colon would result in an invalid
    return value, see issue "#995".
  * Fix a bug in multidicts when passing empty lists as values, see
    issue "#979".
  * Fix a security issue that allows XSS on the Werkzeug debugger. See
    "#1001".
- update to version 0.11.10:
  * Fixed a bug that occurs when running on Python 2.6 and using a
    broken locale.  See pull request #912.
  * Fixed a crash when running the debugger on Google App Engine. See
    issue #925.
  * Fixed an issue with multipart parsing that could cause memory
    exhaustion.
- Update to 0.11.9
  - Corrected an issue that caused the debugger not to use the
    machine GUID on POSIX systems.
  - Corrected an Unicode error on Python 3 for the debugger's
    PIN usage.
  - Corrected the timestamp verification in the pin debug code.
    Without this fix the pin was remebered until too long.
- update to version 0.11.8:
  * fixed a problem with the machine GUID detection code on OS X on
    Python 3.
- changes from version 0.11.7:
  * fixed a regression on Python 3 for the debugger.
- changes from version 0.11.6:
  * werkzeug.serving: Still show the client address on bad requests.
  * improved the PIN based protection for the debugger to make it
    harder to brute force via trying cookies.  Please keep in mind
    that the debugger *is not intended for running on production
    environments*
  * increased the pin timeout to a week to make it less annoying for
    people which should decrease the change that users disable the pin
    check entirely.
  * werkzeug.serving: Fix broken HTTP_HOST when path starts with
    double slash.
- update to version 0.11.5:
  * werkzeug.serving: Fix crash when attempting SSL connection to HTTP
    server.
- update to version 0.11.4:
  * Fixed werkzeug.serving not working from -m flag.
  * Fixed incorrect weak etag handling.
- Rebase 0001_create_a_thread_to_reap_death_process.patch
- Split documentation into own subpackage to speed up build.
